import * as i0 from '@angular/core';
import { input, booleanAttribute, inject, Injector, untracked, effect, Directive, numberAttribute, model, linkedSignal, computed, DestroyRef, InjectionToken, signal, output, afterNextRender, isSignal } from '@angular/core';
import { fromEventPattern, debounceTime } from 'rxjs';
import { Pane } from 'tweakpane';

class NgtTweakBlade {
    constructor() {
        this.hidden = input(false, { transform: booleanAttribute });
        this.disabled = input(false, { transform: booleanAttribute });
        this.injector = inject(Injector);
    }
    get snapshot() {
        return {
            hidden: untracked(this.hidden),
            disabled: untracked(this.disabled),
        };
    }
    startChangeEffect(api) {
        return effect(() => {
            const _api = api();
            if (!_api)
                return;
            _api.hidden = this.hidden();
            _api.disabled = this.disabled();
        }, { injector: this.injector });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakBlade, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.1.5", type: NgtTweakBlade, isStandalone: true, selector: "ngt-tweak-blade", inputs: { hidden: { classPropertyName: "hidden", publicName: "hidden", isSignal: true, isRequired: false, transformFunction: null }, disabled: { classPropertyName: "disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakBlade, decorators: [{
            type: Directive,
            args: [{ selector: 'ngt-tweak-blade' }]
        }] });

class NgtTweakDebounce {
    constructor() {
        this.debounce = input(150, { transform: numberAttribute });
        this.injector = inject(Injector);
    }
    startDebounceEffect(api, cb) {
        return effect((onCleanup) => {
            const _api = api();
            if (!_api)
                return;
            const sub = fromEventPattern((handler) => _api.on('change', handler), (handler) => _api.off('change', handler))
                .pipe(debounceTime(this.debounce()))
                .subscribe((ev) => {
                cb(ev);
            });
            onCleanup(() => {
                sub.unsubscribe();
            });
        }, { injector: this.injector });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakDebounce, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.1.5", type: NgtTweakDebounce, isStandalone: true, inputs: { debounce: { classPropertyName: "debounce", publicName: "debounce", isSignal: true, isRequired: false, transformFunction: null } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakDebounce, decorators: [{
            type: Directive
        }] });

class NgtTweakTitle {
    constructor() {
        this.title = input('TweakPane Title');
        this.injector = inject(Injector);
    }
    get snapshot() {
        return untracked(this.title);
    }
    startChangeEffect(api) {
        return effect(() => {
            const _api = api();
            if (!_api)
                return;
            _api.title = this.title();
        }, { injector: this.injector });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakTitle, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.1.5", type: NgtTweakTitle, isStandalone: true, inputs: { title: { classPropertyName: "title", publicName: "title", isSignal: true, isRequired: false, transformFunction: null } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakTitle, decorators: [{
            type: Directive
        }] });

class NgtTweakFolder {
    constructor() {
        this.expanded = model(false);
        this.title = inject(NgtTweakTitle);
        this.blade = inject(NgtTweakBlade);
        this.parent = inject(NgtTweakFolder, { skipSelf: true, optional: true });
        this.parentFolder = linkedSignal(() => this.parent?.folder());
        this.folder = computed(() => {
            const parent = this.parentFolder();
            if (!parent)
                return null;
            if (!this.isSelf)
                return parent;
            return parent.addFolder({
                title: this.title.snapshot,
                expanded: untracked(this.expanded),
                disabled: this.blade.snapshot.disabled,
                hidden: this.blade.snapshot.hidden,
            });
        });
        this.isSelf = true;
        this.title.startChangeEffect(this.folder);
        this.blade.startChangeEffect(this.folder);
        effect((onCleanup) => {
            const folder = this.folder();
            if (!folder)
                return;
            const cb = (ev) => {
                this.expanded.set(ev.expanded);
            };
            folder.on('fold', cb);
            onCleanup(() => {
                folder.off('fold', cb);
            });
        });
        inject(DestroyRef).onDestroy(() => {
            this.folder()?.dispose();
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakFolder, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.1.5", type: NgtTweakFolder, isStandalone: true, selector: "ngt-tweak-folder", inputs: { expanded: { classPropertyName: "expanded", publicName: "expanded", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { expanded: "expandedChange" }, hostDirectives: [{ directive: NgtTweakTitle, inputs: ["title", "title"] }, { directive: NgtTweakBlade, inputs: ["hidden", "hidden", "disabled", "disabled"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakFolder, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngt-tweak-folder',
                    hostDirectives: [
                        { directive: NgtTweakTitle, inputs: ['title'] },
                        { directive: NgtTweakBlade, inputs: ['hidden', 'disabled'] },
                    ],
                }]
        }], ctorParameters: () => [] });

class NgtTweakLabel {
    constructor() {
        this.label = input('');
        this.tag = input('');
        this.injector = inject(Injector);
    }
    get snapshot() {
        return { label: untracked(this.label), tag: untracked(this.tag) };
    }
    startChangeEffect(api) {
        return effect(() => {
            const _api = api();
            if (!_api)
                return;
            _api.label = this.label();
            if ('tag' in _api) {
                _api.tag = this.tag();
            }
        }, { injector: this.injector });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakLabel, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.1.5", type: NgtTweakLabel, isStandalone: true, inputs: { label: { classPropertyName: "label", publicName: "label", isSignal: true, isRequired: false, transformFunction: null }, tag: { classPropertyName: "tag", publicName: "tag", isSignal: true, isRequired: false, transformFunction: null } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakLabel, decorators: [{
            type: Directive
        }] });

const NGT_TWEAK_BINDING_AS_HOST = new InjectionToken('hostDirective NgtTweakBinding', { factory: () => null });
function provideTweakBindingAsHost(inOut) {
    return { provide: NGT_TWEAK_BINDING_AS_HOST, useValue: inOut ?? true };
}
class NgtTweakBinding {
    get bindableObject() {
        let value = untracked(this.value);
        if (this.asHostDirective && typeof this.asHostDirective === 'object') {
            value = this.asHostDirective.in(value);
        }
        return { value };
    }
    constructor() {
        this.value = model.required();
        this.debounce = inject(NgtTweakDebounce);
        this.label = inject(NgtTweakLabel);
        this.blade = inject(NgtTweakBlade);
        this.parent = inject(NgtTweakFolder);
        this.injector = inject(Injector);
        this.asHostDirective = inject(NGT_TWEAK_BINDING_AS_HOST);
        this.binding = signal(null);
        this.bindingBaseParams = computed(() => ({
            label: this.label.snapshot.label,
            tag: this.label.snapshot.tag,
            disabled: this.blade.disabled(),
            hidden: this.blade.hidden(),
        }));
        this.blade.startChangeEffect(this.binding);
        this.label.startChangeEffect(this.binding);
        this.debounce.startDebounceEffect(this.binding, (ev) => {
            if (this.asHostDirective && typeof this.asHostDirective === 'object') {
                this.value.set(this.asHostDirective.out(ev.value));
            }
            else {
                this.value.set(ev.value);
            }
        });
        if (!this.asHostDirective) {
            this.createBindingEffect(this.bindingBaseParams);
        }
        inject(DestroyRef).onDestroy(() => {
            this.binding()?.dispose();
        });
    }
    createBindingEffect(params) {
        return effect((onCleanup) => {
            const parent = this.parent.folder();
            if (!parent)
                return;
            const bindingParams = { ...this.bindingBaseParams(), ...params() };
            const binding = parent.addBinding(this.bindableObject, 'value', bindingParams);
            this.binding.set(binding);
            onCleanup(() => {
                binding.dispose();
                this.binding.set(null);
            });
        }, { injector: this.injector });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakBinding, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.1.5", type: NgtTweakBinding, isStandalone: true, selector: "ngt-tweak-binding", inputs: { value: { classPropertyName: "value", publicName: "value", isSignal: true, isRequired: true, transformFunction: null } }, outputs: { value: "valueChange" }, hostDirectives: [{ directive: NgtTweakBlade, inputs: ["disabled", "disabled", "hidden", "hidden"] }, { directive: NgtTweakDebounce, inputs: ["debounce", "debounce"] }, { directive: NgtTweakLabel, inputs: ["label", "label", "tag", "tag"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakBinding, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngt-tweak-binding',
                    hostDirectives: [
                        { directive: NgtTweakBlade, inputs: ['disabled', 'hidden'] },
                        { directive: NgtTweakDebounce, inputs: ['debounce'] },
                        { directive: NgtTweakLabel, inputs: ['label', 'tag'] },
                    ],
                }]
        }], ctorParameters: () => [] });

class NgtTweakButton {
    constructor() {
        this.label = input('');
        this.click = output();
        this.title = inject(NgtTweakTitle);
        this.blade = inject(NgtTweakBlade);
        this.parent = inject(NgtTweakFolder);
        this.button = signal(null);
        effect((onCleanup) => {
            const parent = this.parent.folder();
            if (!parent)
                return;
            const button = parent.addButton({
                title: this.title.snapshot,
                hidden: this.blade.snapshot.hidden,
                disabled: this.blade.snapshot.disabled,
                label: untracked(this.label),
            });
            const boundEmit = this.click.emit.bind(this.click);
            button.on('click', boundEmit);
            this.button.set(button);
            onCleanup(() => {
                button.off('click', boundEmit);
            });
        });
        effect(() => {
            const button = this.button();
            if (!button)
                return;
            button.label = this.label();
        });
        this.title.startChangeEffect(this.button);
        this.blade.startChangeEffect(this.button);
        inject(DestroyRef).onDestroy(() => {
            this.button()?.dispose();
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakButton, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.1.5", type: NgtTweakButton, isStandalone: true, selector: "ngt-tweak-button", inputs: { label: { classPropertyName: "label", publicName: "label", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { click: "click" }, hostDirectives: [{ directive: NgtTweakTitle, inputs: ["title", "title"] }, { directive: NgtTweakBlade, inputs: ["hidden", "hidden", "disabled", "disabled"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakButton, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngt-tweak-button',
                    hostDirectives: [
                        { directive: NgtTweakTitle, inputs: ['title'] },
                        { directive: NgtTweakBlade, inputs: ['hidden', 'disabled'] },
                    ],
                }]
        }], ctorParameters: () => [] });

class NgtTweakCheckbox {
    constructor() {
        this.params = input({});
        this.binding = inject(NgtTweakBinding);
        this.binding.createBindingEffect(this.params);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakCheckbox, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.1.5", type: NgtTweakCheckbox, isStandalone: true, selector: "ngt-tweak-checkbox", inputs: { params: { classPropertyName: "params", publicName: "params", isSignal: true, isRequired: false, transformFunction: null } }, providers: [provideTweakBindingAsHost()], hostDirectives: [{ directive: NgtTweakBinding, inputs: ["value", "value"], outputs: ["valueChange", "valueChange"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakCheckbox, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngt-tweak-checkbox',
                    hostDirectives: [{ directive: NgtTweakBinding, inputs: ['value'], outputs: ['valueChange'] }],
                    providers: [provideTweakBindingAsHost()],
                }]
        }], ctorParameters: () => [] });

class NgtTweakColor {
    constructor() {
        this.params = input({});
        this.binding = inject(NgtTweakBinding);
        this.binding.createBindingEffect(this.params);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakColor, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.1.5", type: NgtTweakColor, isStandalone: true, selector: "ngt-tweak-color", inputs: { params: { classPropertyName: "params", publicName: "params", isSignal: true, isRequired: false, transformFunction: null } }, providers: [provideTweakBindingAsHost()], hostDirectives: [{ directive: NgtTweakBinding, inputs: ["value", "value"], outputs: ["valueChange", "valueChange"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakColor, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngt-tweak-color',
                    hostDirectives: [{ directive: NgtTweakBinding, inputs: ['value'], outputs: ['valueChange'] }],
                    providers: [provideTweakBindingAsHost()],
                }]
        }], ctorParameters: () => [] });

class NgtTweakList {
    constructor() {
        this.value = model.required();
        this.options = input.required();
        this.blade = inject(NgtTweakBlade);
        this.debounce = inject(NgtTweakDebounce);
        this.label = inject(NgtTweakLabel);
        this.parent = inject(NgtTweakFolder);
        this.list = signal(null);
        this.listOptions = computed(() => {
            const options = this.options();
            if (Array.isArray(options)) {
                return options.map((option) => ({ value: option, text: `${option}` }));
            }
            return Object.keys(options).map((key) => {
                const value = options[key];
                return { text: key, value };
            });
        });
        this.label.startChangeEffect(this.list);
        this.blade.startChangeEffect(this.list);
        this.debounce.startDebounceEffect(this.list, (ev) => {
            this.value.set(ev.value);
        });
        effect((onCleanup) => {
            const parent = this.parent.folder();
            if (!parent)
                return;
            const list = parent.addBlade({
                view: 'list',
                options: this.listOptions(),
                value: untracked(this.value),
                label: this.label.snapshot.label,
            });
            this.list.set(list);
            onCleanup(() => {
                list.dispose();
            });
        });
        inject(DestroyRef).onDestroy(() => {
            this.list()?.dispose();
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakList, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.1.5", type: NgtTweakList, isStandalone: true, selector: "ngt-tweak-list", inputs: { value: { classPropertyName: "value", publicName: "value", isSignal: true, isRequired: true, transformFunction: null }, options: { classPropertyName: "options", publicName: "options", isSignal: true, isRequired: true, transformFunction: null } }, outputs: { value: "valueChange" }, hostDirectives: [{ directive: NgtTweakBlade, inputs: ["hidden", "hidden", "disabled", "disabled"] }, { directive: NgtTweakDebounce, inputs: ["debounce", "debounce"] }, { directive: NgtTweakLabel, inputs: ["label", "label"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakList, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngt-tweak-list',
                    hostDirectives: [
                        { directive: NgtTweakBlade, inputs: ['hidden', 'disabled'] },
                        { directive: NgtTweakDebounce, inputs: ['debounce'] },
                        { directive: NgtTweakLabel, inputs: ['label'] },
                    ],
                }]
        }], ctorParameters: () => [] });

class NgtTweakNumber {
    constructor() {
        this.params = input({});
        this.binding = inject(NgtTweakBinding);
        this.binding.createBindingEffect(this.params);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakNumber, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.1.5", type: NgtTweakNumber, isStandalone: true, selector: "ngt-tweak-number", inputs: { params: { classPropertyName: "params", publicName: "params", isSignal: true, isRequired: false, transformFunction: null } }, providers: [provideTweakBindingAsHost()], hostDirectives: [{ directive: NgtTweakBinding, inputs: ["value", "value"], outputs: ["valueChange", "valueChange"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakNumber, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngt-tweak-number',
                    hostDirectives: [{ directive: NgtTweakBinding, inputs: ['value'], outputs: ['valueChange'] }],
                    providers: [provideTweakBindingAsHost()],
                }]
        }], ctorParameters: () => [] });

class NgtTweakPane {
    constructor() {
        this.top = input('8px');
        this.right = input('8px');
        this.left = input();
        this.bottom = input();
        this.width = input('256px');
        this.title = inject(NgtTweakTitle, { host: true });
        this.folder = inject(NgtTweakFolder, { host: true });
        this.pane = signal(null);
        this.folder.isSelf = false;
        afterNextRender(() => {
            const pane = new Pane({ title: this.title.title(), expanded: this.folder.expanded() });
            this.pane.set(pane);
            this.folder.parentFolder.set(pane);
        });
        effect(() => {
            this.updateStyleEffect('top');
        });
        effect(() => {
            this.updateStyleEffect('right');
        });
        effect(() => {
            this.updateStyleEffect('left');
        });
        effect(() => {
            this.updateStyleEffect('bottom');
        });
        effect(() => {
            this.updateStyleEffect('width');
        });
    }
    updateStyleEffect(propertyName) {
        const pane = this.pane();
        if (!pane)
            return;
        const parentElement = pane.element.parentElement;
        if (!parentElement)
            return;
        const property = this[propertyName];
        if (!isSignal(property))
            return;
        const value = property();
        if (!value)
            return;
        parentElement.style.setProperty(propertyName, typeof value === 'number' ? value + 'px' : value);
        pane.refresh();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakPane, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.1.5", type: NgtTweakPane, isStandalone: true, selector: "ngt-tweak-pane", inputs: { top: { classPropertyName: "top", publicName: "top", isSignal: true, isRequired: false, transformFunction: null }, right: { classPropertyName: "right", publicName: "right", isSignal: true, isRequired: false, transformFunction: null }, left: { classPropertyName: "left", publicName: "left", isSignal: true, isRequired: false, transformFunction: null }, bottom: { classPropertyName: "bottom", publicName: "bottom", isSignal: true, isRequired: false, transformFunction: null }, width: { classPropertyName: "width", publicName: "width", isSignal: true, isRequired: false, transformFunction: null } }, hostDirectives: [{ directive: NgtTweakFolder, inputs: ["expanded", "expanded"], outputs: ["expandedChange", "expandedChange"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakPane, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngt-tweak-pane',
                    hostDirectives: [{ directive: NgtTweakFolder, inputs: ['expanded'], outputs: ['expandedChange'] }],
                }]
        }], ctorParameters: () => [] });

class NgtTweakPoint {
    constructor() {
        this.params = input({});
        this.binding = inject(NgtTweakBinding);
        this.binding.createBindingEffect(this.params);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakPoint, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.1.5", type: NgtTweakPoint, isStandalone: true, selector: "ngt-tweak-point", inputs: { params: { classPropertyName: "params", publicName: "params", isSignal: true, isRequired: false, transformFunction: null } }, providers: [
            provideTweakBindingAsHost({
                in: (value) => {
                    if (Array.isArray(value)) {
                        const [x, y, z, w] = value;
                        return { x, y, z, w };
                    }
                    return value;
                },
                out: (value) => {
                    const { x, y, z, w } = value;
                    return [x, y, z, w];
                },
            }),
        ], hostDirectives: [{ directive: NgtTweakBinding, inputs: ["value", "value"], outputs: ["valueChange", "valueChange"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakPoint, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngt-tweak-point',
                    hostDirectives: [{ directive: NgtTweakBinding, inputs: ['value'], outputs: ['valueChange'] }],
                    providers: [
                        provideTweakBindingAsHost({
                            in: (value) => {
                                if (Array.isArray(value)) {
                                    const [x, y, z, w] = value;
                                    return { x, y, z, w };
                                }
                                return value;
                            },
                            out: (value) => {
                                const { x, y, z, w } = value;
                                return [x, y, z, w];
                            },
                        }),
                    ],
                }]
        }], ctorParameters: () => [] });

class NgtTweakText {
    constructor() {
        this.params = input({});
        this.binding = inject(NgtTweakBinding);
        this.binding.createBindingEffect(this.params);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakText, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.1.5", type: NgtTweakText, isStandalone: true, selector: "ngt-tweak-text", inputs: { params: { classPropertyName: "params", publicName: "params", isSignal: true, isRequired: false, transformFunction: null } }, providers: [provideTweakBindingAsHost()], hostDirectives: [{ directive: NgtTweakBinding, inputs: ["value", "value"], outputs: ["valueChange", "valueChange"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgtTweakText, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngt-tweak-text',
                    hostDirectives: [{ directive: NgtTweakBinding, inputs: ['value'], outputs: ['valueChange'] }],
                    providers: [provideTweakBindingAsHost()],
                }]
        }], ctorParameters: () => [] });

/**
 * Generated bundle index. Do not edit.
 */

export { NGT_TWEAK_BINDING_AS_HOST, NgtTweakBinding, NgtTweakBlade, NgtTweakButton, NgtTweakCheckbox, NgtTweakColor, NgtTweakDebounce, NgtTweakFolder, NgtTweakLabel, NgtTweakList, NgtTweakNumber, NgtTweakPane, NgtTweakPoint, NgtTweakText, NgtTweakTitle, provideTweakBindingAsHost };
//# sourceMappingURL=angular-three-tweakpane.mjs.map
